@@ -50,15 +50,15 @@ class FilterPropertiesBase(object):
 
     discriminator_value_class_map = {
         'BigRectangularFilterProperties': 'BigRectangularFilterProperties',
-        'MotionWienerFilterProperties': 'MotionWienerFilterProperties',
         'SmallRectangularFilterProperties': 'SmallRectangularFilterProperties',
-        'MedianFilterProperties': 'MedianFilterProperties',
         'DeconvolutionFilterProperties': 'DeconvolutionFilterProperties',
+        'GaussWienerFilterProperties': 'GaussWienerFilterProperties',
+        'SharpenFilterProperties': 'SharpenFilterProperties',
+        'MotionWienerFilterProperties': 'MotionWienerFilterProperties',
+        'MedianFilterProperties': 'MedianFilterProperties',
         'BilateralSmoothingFilterProperties': 'BilateralSmoothingFilterProperties',
         'ConvolutionFilterProperties': 'ConvolutionFilterProperties',
-        'GaussWienerFilterProperties': 'GaussWienerFilterProperties',
-        'GaussianBlurFilterProperties': 'GaussianBlurFilterProperties',
-        'SharpenFilterProperties': 'SharpenFilterProperties'
+        'GaussianBlurFilterProperties': 'GaussianBlurFilterProperties'
     }
 
     def __init__(self, discriminator=None):
